﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.ComponentModel;

namespace TestWinGridPrintingWithFilters
{
    public class AuthenticationObj : INotifyPropertyChanged
    {
        private bool _authenticated;
        private string _associateHash;
        private string _associateNumber;
        private string _associatePIN;
        private string _dateSigned;

        private PropertyChangedEventHandler propertyChangedDelegate;

        public string DateSigned
        {
            get { return _dateSigned; }
            set
            {
                if (this._dateSigned == value)
                {
                    return;
                }
                _dateSigned = value;
                if (this.propertyChangedDelegate != null)
                {
                    this.propertyChangedDelegate(this, new PropertyChangedEventArgs("DateSigned"));
                }
            }
        }

        /// <summary>
        /// Gets or sets a value indicating whether this <see cref="AuthenticationObj"/> is authenticated.
        /// </summary>
        /// <value>
        ///   <c>true</c> if authenticated; otherwise, <c>false</c>.
        /// </value>
        public bool Authenticated
        {
            get { return _authenticated; }
            set
            {
                if (this._authenticated == value)
                {
                    return;
                }

                this._authenticated = value;

                if (this.propertyChangedDelegate != null)
                {
                    this.propertyChangedDelegate(this, new PropertyChangedEventArgs("Authenticated"));
                }
            }
        }

        /// <summary>
        /// Gets or sets the associate hash.
        /// </summary>
        /// <value>
        /// The associate hash.
        /// </value>
        public string AssociateHash
        {
            get { return _associateHash; }
            set
            {
                if (string.Compare(this._associateHash, value, false) == 0)
                {
                    return;
                }
                this._associateHash = value;
                if (this.propertyChangedDelegate != null)
                {
                    this.propertyChangedDelegate(this, new PropertyChangedEventArgs("AssociateHash"));
                }
            }
        }

        /// <summary>
        /// Gets or sets the associate number.
        /// </summary>
        /// <value>
        /// The associate number.
        /// </value>
        public string AssociateNumber
        {
            get { return this._associateNumber; }
            set
            {
                if (this._associateNumber == value)
                {
                    return;
                }
                this._associateNumber = value;
                if (this.propertyChangedDelegate != null)
                {
                    this.propertyChangedDelegate(this, new PropertyChangedEventArgs("AssociateNumber"));
                }
            }
        }

        /// <summary>
        /// Gets or sets the associate PIN.
        /// </summary>
        /// <value>
        /// The associate PIN.
        /// </value>
        public string AssociatePIN
        {
            get { return this._associatePIN; }
            set
            {
                if (this._associatePIN == value)
                {
                    return;
                }
                this._associatePIN = value;
                if (this.propertyChangedDelegate != null)
                {
                    this.propertyChangedDelegate(this, new PropertyChangedEventArgs("AssociatePIN"));
                }
            }
        }

        public AuthenticationObj()
            : this(false, string.Empty, 0, string.Empty, string.Empty)
        {
        }

        /// <summary>
        /// Initializes a new instance of the <see cref="AuthenticationObj"/> class.
        /// </summary>
        /// <param name="authenticated">if set to <c>true</c> [authenticated].</param>
        /// <param name="associateObj">The associate obj.</param>
        /// <param name="assocHash">The assoc hash.</param>
        /// <param name="assocNumber">The assoc number.</param>
        /// <param name="assocPin">The assoc pin.</param>
        public AuthenticationObj(bool authenticated, string assocHash, int assocNumber, string assocPin, string dateSigned)
        {
            Authenticated = authenticated;
            AssociateHash = assocHash;
            AssociateNumber = AssociateNumber;
            AssociatePIN = assocPin;
            DateSigned = dateSigned;
        }

        /// <summary>
        /// Occurs when a property value changes.
        /// </summary>
        public event PropertyChangedEventHandler PropertyChanged
        {
            add
            {
                if (this.propertyChangedDelegate == null)
                {
                    this.propertyChangedDelegate = value;
                }
                else
                {
                    this.propertyChangedDelegate = (PropertyChangedEventHandler)System.Delegate.Combine(this.propertyChangedDelegate, value);
                }
            }
            remove
            {
                if (this.propertyChangedDelegate != null)
                {
                    this.propertyChangedDelegate = (PropertyChangedEventHandler)System.Delegate.Remove(this.propertyChangedDelegate, value);
                }
            }
        }
    }
}
