﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using Infragistics.Win.UltraWinGrid;
using Infragistics.Win;
using Infragistics.Win.UltraWinEditors;
using System.Windows.Forms;
using System.Drawing;

namespace TestWinGridPrintingWithFilters
{
    class CustomCreationFilter : IUIElementCreationFilter
    {
        /// <summary>
        /// Called after an element's ChildElements have been
        /// created. The child element's can be repositioned here
        /// and/or new element's can be added.
        /// </summary>
        /// <param name="parent">The <see cref="T:Infragistics.Win.UIElement"/> whose child elements have been created/positioned.</param>
        public void AfterCreateChildElements(UIElement parent)
        {
            int childElementTextIndex = 0;
            RowCellAreaUIElement row = parent as RowCellAreaUIElement;
            if (row != null && row.HasChildElements)
            {
                for (int i = 1; i < row.ChildElements.Count; i++)
                {
                    if (row.ChildElements[i] is CellUIElement)
                    {
                        CellUIElement nextCell = (CellUIElement)row.ChildElements[i];
                        if (nextCell.Cell.Column.Header.Caption == Constants.TEXT)
                        {
                            childElementTextIndex = nextCell.Cell.Column.Index;
                        }
                        if (nextCell.Cell.EditorComponent != null &&
                            nextCell.Cell.EditorComponent.GetType() == typeof(UltraOptionSet))
                        {
                            UltraGrid grid = GetUltraGrid(parent);
                            using (TextBox tbRadio = new TextBox())
                            using (Graphics graphicsRadio = tbRadio.CreateGraphics())
                            {
                                // - 40 is for the offset of the second band and the scrollbar area, 20 for each
                                tbRadio.Width = grid.Width - nextCell.Cell.Width - 40;
                                tbRadio.WordWrap = true;
                                tbRadio.Text = ((CellUIElement)row.ChildElements[childElementTextIndex]).Cell.Value.ToString();
                                row.Row.Height = (int)Math.Ceiling(graphicsRadio.MeasureString(tbRadio.Text, grid.Font, tbRadio.Width).Height);
                            }
                        }
                    }
                }
            }
        }

        /// <summary>
        /// Gets the ultra grid.
        /// </summary>
        /// <param name="element">The element.</param>
        /// <returns></returns>
        private UltraGrid GetUltraGrid(UIElement element)
        {
            //put this in a utilies file
            if (element.GetType() == typeof(UltraGridUIElement))
            {
                return (UltraGrid)element.GetContext();
            }
            else
            {
                return GetUltraGrid(element.Parent);
            }
        }

        /// <summary>
        /// Called before child elements are to be created/positioned.
        /// This is called during a draw operation for an element
        /// whose ChildElementsDirty is set to true. Returning true from
        /// this method indicates that the default creation logic
        /// should be bypassed.
        /// </summary>
        /// <param name="parent">The <see cref="T:Infragistics.Win.UIElement"/> whose child elements are going to be created/positioned.</param>
        /// <returns>
        /// True if the default creation logic should be bypassed.
        /// </returns>
        public bool BeforeCreateChildElements(UIElement parent)
        {
            //Declare some variables
            Infragistics.Win.OptionSetEmbeddableUIElement objOptionSetUIElement;
            if (parent is Infragistics.Win.OptionSetEmbeddableUIElement)
            {
                objOptionSetUIElement = (Infragistics.Win.OptionSetEmbeddableUIElement)parent;
                objOptionSetUIElement.Rect = new Rectangle(parent.Rect.X, parent.Rect.Y, parent.Rect.Width, 24);
                //((Infragistics.Win.UltraWinGrid.UltraGridRow)objOptionSetUIElement.GetContext(typeof(Infragistics.Win.UltraWinGrid.UltraGridRow))).Appearance.BackColor = Color.White;
                //This will make sure the child elements (radio button and text UI Element) get drawn after the rectangle for the
                //OptionSet is resized.
                return false;
            }
            return false;
        }
    }
}
