﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using Infragistics.Win;
using Infragistics.Win.UltraWinGrid;
using System.Windows.Forms;
using System.Drawing;

namespace TestWinGridPrintingWithFilters
{
    class CustomDrawFilter : IUIElementDrawFilter
    {
        /// <summary>
        /// Called during the drawing operation of a UIElement for a specific phase
        /// of the operation. This will only be called for the phases returned
        /// from the GetPhasesToFilter method.
        /// </summary>
        /// <param name="drawPhase">Contains a single bit which identifies the current draw phase.</param>
        /// <param name="drawParams">The <see cref="T:Infragistics.Win.UIElementDrawParams"/> used to provide rendering information.</param>
        /// <returns>
        /// Returning true from this method indicates that this phase has been handled and the default processing should be skipped.
        /// </returns>
        public bool DrawElement(Infragistics.Win.DrawPhase drawPhase, ref Infragistics.Win.UIElementDrawParams drawParams)
        {
            switch (drawPhase)
            {
                case DrawPhase.BeforeDrawBorders:
                    return false;
                case DrawPhase.AfterDrawElement:
                    if (drawParams.Element is RowCellAreaUIElement)
                    {
                        RowCellAreaUIElement aCellUIElement = (RowCellAreaUIElement)drawParams.Element;
                        if (aCellUIElement.Row.Cells.Exists(Constants.BOTTOM_LINE) &&
                            aCellUIElement.Row.Cells[Constants.TYPE].Value != DBNull.Value &&
                            Convert.ToBoolean(DataConverters.INOConvertInt32(aCellUIElement.Row.Cells[Constants.BOTTOM_LINE].Value.ToString(), 0)))
                        {
                            if (aCellUIElement.Row.Cells[Constants.TYPE].Value.ToString() != Constants.TEXT ||
                                aCellUIElement.Row.Index == aCellUIElement.Row.ParentRow.ChildBands[aCellUIElement.Row.Band.Key].Rows.Count - 1)
                            {
                                drawParams.DrawBorders(UIElementBorderStyle.Solid, Border3DSide.Bottom, Rectangle.Inflate(aCellUIElement.Rect, 0, 0));
                            }
                        }
                        //if this is a procedure row, meaning it has a parent but it is not the main row,
                        //then draw a line under the last cell
                        else if (aCellUIElement.Row.HasParent() && aCellUIElement.Row.ParentRow.Band.Index != 0 &&
                            aCellUIElement.Row.Index == aCellUIElement.Row.ParentRow.ChildBands[0].Rows.Count - 1)
                        {
                            drawParams.DrawBorders(UIElementBorderStyle.Solid, Border3DSide.Bottom, Rectangle.Inflate(aCellUIElement.Rect, 0, 0));
                        }
                    }
                    else
                    {
                        CellUIElement aCellUIElement = (CellUIElement)drawParams.Element;
                        //look to see if the type is texbox, then draw the full border around the cell
                        if (aCellUIElement.Column.Header.Caption == Constants.CONTROL && aCellUIElement.Row.Cells.Exists(Constants.TYPE) &&
                            aCellUIElement.Row.Cells[Constants.TYPE].Value.ToString() == Constants.TEXTBOX)
                        {
                            if (aCellUIElement.Row.ParentRow.ChildBands[aCellUIElement.Row.Band.Key].Rows.Count == 1)
                            {
                                drawParams.DrawBorders(UIElementBorderStyle.Solid, Border3DSide.All, Rectangle.Inflate(aCellUIElement.Rect, 0, 0));
                            }
                            else
                            {
                                drawParams.DrawBorders(UIElementBorderStyle.Solid, Border3DSide.Right, Rectangle.Inflate(aCellUIElement.Rect, 0, 0));
                                drawParams.DrawBorders(UIElementBorderStyle.Solid, Border3DSide.Left, Rectangle.Inflate(aCellUIElement.Rect, 0, 0));
                                if (aCellUIElement.Row.Index == 0)
                                {
                                    drawParams.DrawBorders(UIElementBorderStyle.Solid, Border3DSide.Top, Rectangle.Inflate(aCellUIElement.Rect, 0, 0));
                                }
                                else if (aCellUIElement.Row.Index == (aCellUIElement.Row.ParentRow.ChildBands[aCellUIElement.Row.Band.Key].Rows.Count - 1))
                                {
                                    drawParams.DrawBorders(UIElementBorderStyle.Solid, Border3DSide.Bottom, Rectangle.Inflate(aCellUIElement.Rect, 0, 0));
                                }
                            }
                        }
                        else if (aCellUIElement.Column.Header.Caption == Constants.TEXT && aCellUIElement.Row.Cells.Exists(Constants.TYPE) &&
                            aCellUIElement.Row.Cells[Constants.TYPE].Value.ToString() == Constants.HEADER)
                        {
                            drawParams.DrawBorders(UIElementBorderStyle.Solid, Border3DSide.All, Rectangle.Inflate(aCellUIElement.Rect, 0, 0));
                        }
                        else if (aCellUIElement.Column.Header.Caption == Constants.CONTROL && aCellUIElement.Row.Cells.Exists(Constants.TYPE) &&
                            aCellUIElement.Row.Cells[Constants.TYPE].Value.ToString() == Constants.COMBO)
                        {
                            drawParams.DrawBorders(UIElementBorderStyle.Solid, Border3DSide.All, Rectangle.Inflate(aCellUIElement.Rect, 0, 0));
                        }
                    }
                    return true;
                case DrawPhase.BeforeDrawFocus:
                    if (drawParams.Element is OptionSetOptionButtonUIElement)
                    {
                        //drawParams.DrawBorders(UIElementBorderStyle.None, Border3DSide.All);
                    }
                    return true;
            }
            return true;
        }

        /// <summary>
        /// Called before each element is about to be drawn.
        /// </summary>
        /// <param name="drawParams">The <see cref="T:Infragistics.Win.UIElementDrawParams"/> used to provide rendering information.</param>
        /// <returns>
        /// Bit flags indicating which phases of the drawing operation to filter. The DrawElement method will be called only for those phases.
        /// </returns>
        public Infragistics.Win.DrawPhase GetPhasesToFilter(ref Infragistics.Win.UIElementDrawParams drawParams)
        {
            if (drawParams.Element is RowCellAreaUIElement)
            {
                return DrawPhase.AfterDrawElement | DrawPhase.BeforeDrawBorders | DrawPhase.BeforeDrawFocus;
            }
            else if (drawParams.Element is CellUIElement)
            {
                return DrawPhase.AfterDrawElement | DrawPhase.BeforeDrawFocus;
            }
            return DrawPhase.BeforeDrawFocus;
        }
    }
}
