﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Data;

namespace TestWinGridPrintingWithFilters
{
    public class DocCompletionObj
    {
        
        #region CONSTANTS
        private const string SUBMISSION_ID = "SUBMISSION ID";
        private const string SCORE = "SCORE";
        private const string COMMENTS = "COMMENTS";
        private const string QUESTION_ID = "QUESTION ID";
        private const string ORDER_ID = "ORDER ID";
        private const string FORM_ID = "FORM ID";
        private const int ZERO = 0; 
        #endregion

        private int _requiredQuestionCount;

        #region Properties
        public bool FormIsDirty { get; set; }
        /// <summary>
        /// Gets or sets the document answers.
        /// </summary>
        /// <value>
        /// The document answers.
        /// </value>
        public DataSet DocumentAnswers { get; set; }
        /// <summary>
        /// Gets or sets the required question count.
        /// </summary>
        /// <value>
        /// The required question count.
        /// </value>
        public int RequiredQuestionCount { get; set; }
        /// <summary>
        /// Gets or sets a value indicating whether [questions complete].
        /// </summary>
        /// <value>
        ///   <c>true</c> if [questions complete]; otherwise, <c>false</c>.
        /// </value>
        public bool QuestionsComplete { get; set; }
        /// <summary>
        /// Gets or sets a value indicating whether [form complete].
        /// </summary>
        /// <value>
        ///   <c>true</c> if [form complete]; otherwise, <c>false</c>.
        /// </value>
        public bool FormComplete { get; set; }
        /// <summary>
        /// Gets or sets the required signature count.
        /// </summary>
        /// <value>
        /// The required signature count.
        /// </value>
        public int RequiredSignatureCount { get; set; }
        /// <summary>
        /// Gets or sets the required answer count.
        /// </summary>
        /// <value>
        /// The required answer count.
        /// </value>
        public int RequiredAnswerCount { get; set; }
        #endregion

        /// <summary>
        /// Initializes a new instance of the <see cref="DocCompletionObj"/> class.
        /// </summary>
        public DocCompletionObj()
        {
            DocumentAnswers = new DataSet();
            DocumentAnswers.Tables.Add();
            DocumentAnswers.Tables[ZERO].Columns.Add(SUBMISSION_ID);
            DocumentAnswers.Tables[ZERO].Columns.Add(SCORE);
            DocumentAnswers.Tables[ZERO].Columns.Add(COMMENTS);
            DocumentAnswers.Tables[ZERO].Columns.Add(QUESTION_ID);
            DocumentAnswers.Tables[ZERO].Columns.Add(ORDER_ID);
            DocumentAnswers.Tables[ZERO].Columns.Add(FORM_ID);
        }

        /// <summary>
        /// Adds the question.
        /// </summary>
        /// <param name="newRow">The new row.</param>
        public void AddQuestion(DataRow newRow, bool required)
        {
            foreach (DataRow dr in DocumentAnswers.Tables[0].Rows)
            {
                if (dr[QUESTION_ID] == newRow[QUESTION_ID])
                {
                    dr.Delete();
                    if (required)
                    {
                        RequiredAnswerCount--;
                    }
                }
            }
            DocumentAnswers.AcceptChanges();
            DataRow addRow = DocumentAnswers.Tables[0].NewRow();
            addRow.ItemArray = newRow.ItemArray;
            DocumentAnswers.Tables[0].Rows.Add(addRow);
            DocumentAnswers.AcceptChanges();
            if (required)
            {
                RequiredAnswerCount++;
            }
            FormIsDirty = true;
            CheckQuestionsComplete();
        }

        /// <summary>
        /// Checks the questions complete.
        /// </summary>
        public void CheckQuestionsComplete()
        {
            if (RequiredAnswerCount == RequiredQuestionCount)
            {
                QuestionsComplete = true;
            }
            else
            {
                QuestionsComplete = false;
            }
        }

        /// <summary>
        /// Removes the question.
        /// </summary>
        /// <param name="questionID">The question ID.</param>
        public void RemoveQuestion(string questionID, bool required)
        {
            foreach (DataRow dr in DocumentAnswers.Tables[0].Rows)
            {
                if (dr[QUESTION_ID].ToString() == questionID)
                {
                    dr.Delete();
                }
            }
            DocumentAnswers.AcceptChanges();
            if (required)
            {
                QuestionsComplete = false;
                RequiredAnswerCount--;
            }
        }
    }
}
