﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using System.IO;
using Infragistics.Win.UltraWinGrid;
using Infragistics.Win;
using Infragistics.Win.UltraWinEditors;

namespace TestWinGridPrintingWithFilters
{
    public partial class Form1 : Form
    {
        private const string PARENT_ID = "ParentID";
        private const string ONE = "1";
        private const string TWO = "2";
        private const string THREE = "3";
        private const string FOUR = "4";
        private const string TEXT_FORMAT = "{0} {1}\n{2}";

        /// <summary>
        /// Gets or sets the current page number.
        /// </summary>
        /// <value>
        /// The current page number.
        /// </value>
        public int CurrentPageNumber { get; set; }
        DocCompletionObj DocCompletion = new DocCompletionObj();

        public Form1()
        {
            InitializeComponent();
        }

        private void Form1_Load(object sender, EventArgs e)
        {
            gridQuestions.CreationFilter = new CustomCreationFilter();
            gridQuestions.DrawFilter = new CustomDrawFilter();
            CreateDataSet();
        }

        private void CreateDataSet()
        {
            int requiredQuestionCount = 0;
            int requiredSignatureCount = 0;
            string comments;
            int score;

            DataSet GridDataSource = new DataSet();
            DataSet ds = new DataSet();
            StringReader sr = new StringReader(Properties.Resources.Text);
            ds.ReadXml(sr);
            GridDataSource.Tables.Add();
            GridDataSource.Tables[Constants.ZERO].Columns.Add(PARENT_ID);
            DataRow dr = GridDataSource.Tables[Constants.ZERO].NewRow();
            dr[Constants.ZERO] = Constants.ONE;
            GridDataSource.Tables[Constants.ZERO].Rows.Add(dr);
            DataSet returnSet;
            returnSet = ds;

            int tableID = Constants.ONE;
            int textColumnIndex = returnSet.Tables[Constants.ZERO].Columns.IndexOf(Constants.TEXT);
            DataTable dt = new DataTable();
            foreach (DataColumn dc in returnSet.Tables[Constants.ZERO].Columns)
            {
                dt.Columns.Add(dc.ColumnName);
            }
            DataRow dtDR;
            foreach (DataRow dataRow in returnSet.Tables[Constants.ZERO].Rows)
            {
                //don't know why i have to redeclare the type, but if i dont, it seems
                //like all redio button controls are related, and when one is selected, the others are deselected
                dt.Columns[Constants.CONTROL].DataType = typeof(object);
                dt.Rows.Clear();
                dtDR = dt.NewRow();
                dtDR.ItemArray = dataRow.ItemArray;
                dt.Rows.Add(dtDR);
                if (dt.Rows[Constants.ZERO][Constants.TYPE].ToString() == Constants.TEXT || dt.Rows[Constants.ZERO][Constants.TYPE].ToString() == Constants.SUMMARY ||
                    dt.Rows[Constants.ZERO][Constants.TYPE].ToString() == Constants.DOCUMENT_SUMMARY || dt.Rows[Constants.ZERO][Constants.TYPE].ToString() == Constants.HEADER ||
                    dt.Rows[Constants.ZERO][Constants.TYPE].ToString() == Constants.SPACE || dt.Rows[Constants.ZERO][Constants.TYPE].ToString() == Constants.PAGE_BREAK)
                {
                    dt.Columns.Remove(Constants.CONTROL);
                    dt.AcceptChanges();
                    if (dt.Rows[0][Constants.TYPE].ToString() == Constants.TEXT)
                    {
                        AddRowsToTextDataTable(dt);
                    }
                }
                else if (dt.Rows[Constants.ZERO][Constants.TYPE].ToString() == Constants.SIGNATURE || dt.Rows[Constants.ZERO][Constants.TYPE].ToString() == Constants.SATISFACTION
                    || dt.Rows[Constants.ZERO][Constants.TYPE].ToString() == Constants.EXPECTATIONS || dt.Rows[Constants.ZERO][Constants.TYPE].ToString() == Constants.CORPORATE_EXPECTATIONS)
                {
                    dt.Columns.Remove(Constants.TEXT);
                    dt.AcceptChanges();
                }
                else if (dt.Rows[Constants.ZERO][Constants.TYPE].ToString() == Constants.TEXTBOX)
                {
                    AddRowsToTextboxDataTable(dt);
                }
                if (Convert.ToBoolean(Convert.ToInt32(dataRow[Constants.REQUIRED].ToString())))
                {
                    if (dataRow[Constants.TYPE].ToString() == Constants.SIGNATURE)
                    {
                        requiredSignatureCount++;
                    }
                    else
                    {
                        requiredQuestionCount++;
                    }
                }
                //adds the value to the DocCompleteObject that keeps track of the scores
                if (dataRow[Constants.CONTROL] != DBNull.Value)
                {
                    comments = string.Empty;
                    score = DataConverters.INOConvertInt32(dataRow[Constants.CONTROL].ToString(), 0);
                    if (score == 0)
                    {
                        comments = dataRow[Constants.CONTROL].ToString();
                    }
                    //ValueSelected(comments, score, dataRow[Constants.ROW_ID].ToString(), Convert.ToBoolean(Convert.ToInt32(dataRow[Constants.REQUIRED].ToString())));

                }
                GridDataSource.Tables.Add(dt.Copy());
                GridDataSource.Relations.Add(new DataRelation(tableID.ToString(), GridDataSource.Tables[Constants.ZERO].Columns[Constants.ZERO], GridDataSource.Tables[tableID].Columns[Constants.ZERO]));
                tableID++;
                if (!dt.Columns.Contains(Constants.CONTROL))
                {
                    dt.Columns.Add(Constants.CONTROL, typeof(object));
                }
                if (!dt.Columns.Contains(Constants.TEXT))
                {
                    dt.Columns.Add(Constants.TEXT);
                    dt.Columns[Constants.TEXT].SetOrdinal(textColumnIndex);
                }
            }
            DocCompletion.RequiredQuestionCount = requiredQuestionCount;
            DocCompletion.RequiredSignatureCount = requiredSignatureCount;
            DocCompletion.CheckQuestionsComplete();
            GridDataSource.AcceptChanges();
            gridQuestions.DataSource = GridDataSource;
            gridQuestions.UpdateData();
            gridQuestions.ActiveRow = null;
            DocCompletion.FormIsDirty = false;
        }

        /// <summary>
        /// Adds the rows to text data table.
        /// </summary>
        /// <param name="dt">The dt.</param>
        private void AddRowsToTextDataTable(DataTable dt)
        {
            using (TextBox tb = new TextBox())
            {
                tb.Size = new Size(gridQuestions.Width - 80, Constants.TWENTY);
                tb.Multiline = true;
                using (Graphics graphics = tb.CreateGraphics())
                {
                    //adding 2 because the first row of text contains 2 extra pixels, not sure why
                    int maxRowHeight = (gridQuestions.Font.Height * 5) + 2;
                    string[] arrayOfAnswer = SplitStringBySpacesAndLineFeeds(dt.Rows[0][Constants.TEXT].ToString());
                    List<string> listOfAnswers = new List<string>();
                    StringBuilder sb = new StringBuilder();
                    foreach (string answerSection in arrayOfAnswer)
                    {
                        if (!string.IsNullOrEmpty(answerSection))
                        {
                            sb.Append(answerSection);
                            if (graphics.MeasureString(sb.ToString(), gridQuestions.Font, tb.Width).Height > maxRowHeight)
                            {
                                listOfAnswers.Add(sb.ToString().Remove(sb.ToString().LastIndexOf(answerSection)));
                                sb = new StringBuilder();
                                sb.Append(answerSection);
                            }
                        }
                    }
                    listOfAnswers.Add(sb.ToString());
                    dt.Rows[0][Constants.TEXT] = listOfAnswers[0];
                    for (int i = 1; i < listOfAnswers.Count; i++)
                    {
                        DataRow dr = dt.NewRow();
                        dr.ItemArray = dt.Rows[0].ItemArray;
                        dr[Constants.TEXT] = listOfAnswers[i];
                        dt.Rows.Add(dr);
                    }
                    dt.AcceptChanges();
                }
            }
        }

        /// <summary>
        /// Splits the string by spaces and line feeds.
        /// </summary>
        /// <param name="stringToSplit">The string to split.</param>
        /// <returns></returns>
        private string[] SplitStringBySpacesAndLineFeeds(string stringToSplit)
        {
            string[] carriageReturn = new string[] { Constants.CARRIAGE_RETURN };
            int countSplitByCarriageReturn = stringToSplit.Split(new string[] { Constants.CARRIAGE_RETURN }, StringSplitOptions.None).Count();
            string[] splitBySpaces = stringToSplit.Split(' ');
            string[] splitString = new string[countSplitByCarriageReturn + splitBySpaces.Count()];
            int carriageReturnCount = Constants.ZERO;
            try
            {
                for (int i = Constants.ZERO; i < splitBySpaces.Count(); i++)
                {
                    string[] carriageReturnSplit = splitBySpaces[i].Split(carriageReturn, StringSplitOptions.None);
                    if (carriageReturnSplit.Count() > Constants.ONE)
                    {
                        //do a for loop here, and if it is the last one, don't add a carriage return, add a space
                        for (int innerI = Constants.ZERO; innerI < carriageReturnSplit.Count(); innerI++)
                        {
                            //if this is the last one, need to add a space, not a carriage return
                            if (innerI == (carriageReturnSplit.Count() - Constants.ONE))
                            {
                                splitString[i + carriageReturnCount] = carriageReturnSplit[innerI].Insert(carriageReturnSplit[innerI].Length, Constants.SPACE_1);
                            }
                            else
                            {
                                splitString[i + carriageReturnCount] = carriageReturnSplit[innerI].Insert(carriageReturnSplit[innerI].Length, Constants.CARRIAGE_RETURN);
                                carriageReturnCount++;
                            }
                        }
                    }
                    else
                    {
                        if (i == (splitBySpaces.Count() - Constants.ONE))
                        {
                            splitString[i + carriageReturnCount] = splitBySpaces[i];
                        }
                        else
                        {
                            splitString[i + carriageReturnCount] = splitBySpaces[i].Insert(splitBySpaces[i].Length, Constants.SPACE_1);
                        }
                    }
                }
            }
            catch (Exception)
            {
                //do nothing
            }
            return splitString;
        }

        /// <summary>
        /// Adds the rows to text data table.
        /// </summary>
        /// <param name="dt">The dt.</param>
        private void AddRowsToTextboxDataTable(DataTable dt)
        {
            using (TextBox tb = new TextBox())
            {
                tb.Size = new Size(gridQuestions.Width - Constants.THREE_TWENTY, Constants.TWENTY);
                tb.Multiline = true;
                using (Graphics graphics = tb.CreateGraphics())
                {
                    //adding 2 because the first row of text contains 2 extra pixels, not sure why
                    int maxRowHeight = (gridQuestions.Font.Height * 5) + 2;
                    string[] arrayOfAnswer = SplitStringBySpacesAndLineFeeds(dt.Rows[0][Constants.CONTROL].ToString());
                    List<string> listOfAnswers = new List<string>();
                    StringBuilder sb = new StringBuilder();
                    foreach (string answerSection in arrayOfAnswer)
                    {
                        if (!string.IsNullOrEmpty(answerSection))
                        {
                            sb.Append(answerSection);
                            if (graphics.MeasureString(sb.ToString(), gridQuestions.Font, tb.Width).Height > maxRowHeight)
                            {
                                listOfAnswers.Add(sb.ToString().Remove(sb.ToString().LastIndexOf(answerSection)));
                                sb = new StringBuilder();
                                sb.Append(answerSection);
                            }
                        }
                    }
                    listOfAnswers.Add(sb.ToString());
                    dt.Rows[0][Constants.CONTROL] = listOfAnswers[0];
                    for (int i = 1; i < listOfAnswers.Count; i++)
                    {
                        DataRow dr = dt.NewRow();
                        dr.ItemArray = dt.Rows[0].ItemArray;
                        dr[Constants.TEXT] = string.Empty;
                        dr[Constants.CONTROL] = listOfAnswers[i];
                        dt.Rows.Add(dr);
                    }
                    dt.AcceptChanges();
                }
            }
        }

        /// <summary>
        /// Handles the InitializeRow event of the gridQuestions control.
        /// </summary>
        /// <param name="sender">The source of the event.</param>
        /// <param name="e">The <see cref="Infragistics.Win.UltraWinGrid.InitializeRowEventArgs"/> instance containing the event data.</param>
        private void gridQuestions_InitializeRow(object sender, Infragistics.Win.UltraWinGrid.InitializeRowEventArgs e)
        {
            if (e.Row.Band.Index != Constants.ZERO && e.Row.Band.Columns.Exists(Constants.CONTROL))
            {
                if (e.Row.Cells[Constants.CONTROL].EditorComponent == null)
                {
                    switch (e.Row.Cells[Constants.TYPE].Value.ToString().Trim())
                    {
                        case Constants.RADIO:
                            RowIsRadio(e);
                            break;
                        case Constants.TEXTBOX:
                            e.Row.Band.Columns[Constants.TEXT].MaxWidth = Constants.THREE_HUNDRED;
                            break;
                        case Constants.COMBO:
                            RowIsCombo(e);
                            break;
                        case Constants.SIGNATURE:
                            RowIsSignature(e);
                            break;
                    }
                }
            }
            else if (e.Row.Band.Index == Constants.ZERO)
            {
                e.Row.ExpandAll();
                e.Row.Appearance.BackColor = Color.White;
                e.Row.Appearance.ForeColor = Color.White;
                e.Row.Band.Override.SelectedAppearancesEnabled = DefaultableBoolean.False;
                e.Row.Band.Override.ActiveAppearancesEnabled = DefaultableBoolean.False;
            }
            //center the Text in the Textboxes only, or the Summary Cells
            else if (e.Row.Band.Index != Constants.ZERO && e.Row.Cells.Exists(Constants.TEXT))
            {
                RowDoesntContainControl(e);
            }
        }

        /// <summary>
        /// Handles the InitializeLayout event of the gridQuestions control.
        /// </summary>
        /// <param name="sender">The source of the event.</param>
        /// <param name="e">The <see cref="Infragistics.Win.UltraWinGrid.InitializeLayoutEventArgs"/> instance containing the event data.</param>
        private void gridQuestions_InitializeLayout(object sender, Infragistics.Win.UltraWinGrid.InitializeLayoutEventArgs e)
        {
            e.Layout.Bands[Constants.ZERO].Indentation = Constants.ZERO;
            e.Layout.Bands[Constants.ZERO].ColHeadersVisible = false;
            e.Layout.Override.AllowDelete = DefaultableBoolean.False;
            e.Layout.Override.CellClickAction = Infragistics.Win.UltraWinGrid.CellClickAction.RowSelect;
            e.Layout.RowConnectorStyle = Infragistics.Win.UltraWinGrid.RowConnectorStyle.None;
            e.Layout.Override.RowSizing = Infragistics.Win.UltraWinGrid.RowSizing.AutoFree;
            e.Layout.Override.CellMultiLine = DefaultableBoolean.True;
            e.Layout.Override.BorderStyleRow = UIElementBorderStyle.None;
            e.Layout.Override.BorderStyleCell = UIElementBorderStyle.None;
            e.Layout.InterBandSpacing = Constants.SIX;
            e.Layout.Override.ActiveCellAppearance.BorderColor = Color.Transparent;
            //e.Layout.Override.ActiveRowAppearance.BorderColor = Color.Transparent;
            e.Layout.Override.ActiveRowAppearance = e.Layout.Override.RowAppearance;
            e.Layout.Override.ActiveRowAppearance.ForeColor = Color.Black;
            HideUnnecessaryColumns(e);
        }

        /// <summary>
        /// Hides the unnecessary columns.
        /// </summary>
        /// <param name="e">The <see cref="Infragistics.Win.UltraWinGrid.InitializeLayoutEventArgs"/> instance containing the event data.</param>
        private void HideUnnecessaryColumns(InitializeLayoutEventArgs e)
        {
            for (int i = 1; i < e.Layout.Bands.Count; i++)
            {
                e.Layout.Bands[i].ColHeadersVisible = false;
                if (e.Layout.Bands[i].Columns.Exists(Constants.PARENT_ID))
                {
                    e.Layout.Bands[i].Columns[Constants.PARENT_ID].Hidden = true;
                }
                e.Layout.Bands[i].Columns[Constants.ROW_ID].Hidden = true;
                if (e.Layout.Bands[i].Columns.Exists(Constants.TYPE))
                {
                    e.Layout.Bands[i].Columns[Constants.TYPE].Hidden = true;
                }
                if (e.Layout.Bands[i].Columns.Exists(Constants.GROUP_ID))
                {
                    e.Layout.Bands[i].Columns[Constants.GROUP_ID].Hidden = true;
                }
                if (e.Layout.Bands[i].Columns.Exists(Constants.HEIGHT))
                {
                    e.Layout.Bands[i].Columns[Constants.HEIGHT].Hidden = true;
                }
                if (e.Layout.Bands[i].Columns.Exists(Constants.PRECISION))
                {
                    e.Layout.Bands[i].Columns[Constants.PRECISION].Hidden = true;
                }
                if (e.Layout.Bands[i].Columns.Exists(Constants.REQUIRED))
                {
                    e.Layout.Bands[i].Columns[Constants.REQUIRED].Hidden = true;
                }
                if (e.Layout.Bands[i].Columns.Exists(Constants.RESPONSES))
                {
                    e.Layout.Bands[i].Columns[Constants.RESPONSES].Hidden = true;
                }
                if (e.Layout.Bands[i].Columns.Exists(Constants.PROCEDURE))
                {
                    e.Layout.Bands[i].Columns[Constants.PROCEDURE].Hidden = true;
                }
                if (e.Layout.Bands[i].Columns.Exists(Constants.SIZE))
                {
                    e.Layout.Bands[i].Columns[Constants.SIZE].Hidden = true;
                }
                if (e.Layout.Bands[i].Columns.Exists(Constants.GROUP_NAME))
                {
                    e.Layout.Bands[i].Columns[Constants.GROUP_NAME].Hidden = true;
                }
                if (e.Layout.Bands[i].Columns.Exists(Constants.NAME))
                {
                    e.Layout.Bands[i].Columns[Constants.NAME].Hidden = true;
                }
                if (e.Layout.Bands[i].Columns.Exists(Constants.JOB_LEVELS))
                {
                    e.Layout.Bands[i].Columns[Constants.JOB_LEVELS].Hidden = true;
                }
                if (e.Layout.Bands[i].Columns.Exists(Constants.CAN_BE_ANSWERED))
                {
                    e.Layout.Bands[i].Columns[Constants.CAN_BE_ANSWERED].Hidden = true;
                }
                if (e.Layout.Bands[i].Columns.Exists(Constants.SHOW_TEXT))
                {
                    e.Layout.Bands[i].Columns[Constants.SHOW_TEXT].Hidden = true;
                }
                if (e.Layout.Bands[i].Columns.Exists(Constants.BOTTOM_LINE))
                {
                    e.Layout.Bands[i].Columns[Constants.BOTTOM_LINE].Hidden = true;
                }
                if (e.Layout.Bands[i].Columns.Exists(Constants.BOLD))
                {
                    e.Layout.Bands[i].Columns[Constants.BOLD].Hidden = true;
                }
                if (e.Layout.Bands[i].Columns.Exists(Constants.ITALICS))
                {
                    e.Layout.Bands[i].Columns[Constants.ITALICS].Hidden = true;
                }
                if (e.Layout.Bands[i].Columns.Exists(Constants.UNDERLINE))
                {
                    e.Layout.Bands[i].Columns[Constants.UNDERLINE].Hidden = true;
                }
                if (e.Layout.Bands[i].Columns.Exists(Constants.CONTROL))
                {
                    e.Layout.Bands[i].Columns[Constants.CONTROL].CellClickAction = CellClickAction.Edit;
                    e.Layout.Bands[i].Columns[Constants.CONTROL].ButtonDisplayStyle = Infragistics.Win.UltraWinGrid.ButtonDisplayStyle.Always;
                }
                if (e.Layout.Bands[i].Columns.Exists(Constants.TEXT))
                {
                    e.Layout.Bands[i].Columns[Constants.TEXT].TabStop = false;
                }
                //this looks to see if it is a second layer band, not a third, because we still want offset on third layer band
                if (e.Layout.Bands[i].ParentBand != null && e.Layout.Bands[i].ParentBand.ParentBand == null)
                {
                    e.Layout.Bands[i].Indentation = 0;
                }
            }
        }

        /// <summary>
        /// Rows the doesnt contain control.
        /// </summary>
        /// <param name="e">The <see cref="Infragistics.Win.UltraWinGrid.InitializeRowEventArgs"/> instance containing the event data.</param>
        private void RowDoesntContainControl(InitializeRowEventArgs e)
        {
            if (e.Row.Cells[Constants.TYPE].Value.ToString() == Constants.HEADER)
            {
                e.Row.Cells[Constants.TEXT].Appearance.FontData.Bold = DefaultableBoolean.True;
                //e.Row.Cells[Constants.TEXT].Appearance.FontData.Underline = DefaultableBoolean.True;
                e.Row.Cells[Constants.TEXT].Appearance.TextHAlign = HAlign.Center;
                e.Row.Cells[Constants.TEXT].Appearance.ForeColor = Color.FromArgb(223, 0, 49);
                e.Row.Cells[Constants.TEXT].Appearance.BackColor = Color.FromArgb(249, 245, 0);
                e.Row.Band.Override.SelectedAppearancesEnabled = DefaultableBoolean.False;
                e.Row.Band.Override.ActiveAppearancesEnabled = DefaultableBoolean.False;
                e.Row.Cells[Constants.TEXT].Appearance.FontData.Name = Constants.CAMBRIA;
            }
            else if (e.Row.Cells[Constants.TYPE].Value.ToString() == Constants.SPACE)
            {
                e.Row.Cells[Constants.TEXT].Value = null;
                e.Row.Height = DataConverters.INOConvertInt32(e.Row.Cells[Constants.HEIGHT].Value.ToString(), Constants.ZERO);
            }
            else if (e.Row.Cells[Constants.TYPE].Value.ToString() == Constants.PAGE_BREAK)
            {
                e.Row.Cells[Constants.TEXT].Value = null;
                e.Row.Height = DataConverters.INOConvertInt32(e.Row.Cells[Constants.HEIGHT].Value.ToString(), Constants.ZERO);
                e.Row.Appearance.BackColor = Color.FromArgb(223, 0, 49);
                e.Row.Band.Override.SelectedAppearancesEnabled = DefaultableBoolean.False;
                e.Row.Band.Override.ActiveAppearancesEnabled = DefaultableBoolean.False;
                e.Row.Cells[Constants.TEXT].Activation = Activation.Disabled;
            }
            else if (e.Row.Cells[Constants.TYPE].Value.ToString() == Constants.SUMMARY ||
                e.Row.Cells[Constants.TYPE].Value.ToString() == Constants.DOCUMENT_SUMMARY)
            {
                e.Row.Cells[Constants.TEXT].Appearance.BackColor = Color.WhiteSmoke;
                e.Row.Band.Override.SelectedAppearancesEnabled = DefaultableBoolean.False;
                e.Row.Band.Override.ActiveAppearancesEnabled = DefaultableBoolean.False;
                e.Row.Cells[Constants.TEXT].Appearance.TextHAlign = HAlign.Center;
                e.Row.Cells[Constants.TEXT].Appearance.FontData.Bold = DefaultableBoolean.True;
                //e.Row.Cells[Constants.TEXT].Appearance.FontData.Underline = DefaultableBoolean.True;
                //e.Row.Cells[Constants.TEXT].Appearance.FontData.Name = "Times New Roman";
            }
            e.Row.Cells[Constants.TEXT].Appearance.FontData.SizeInPoints = DataConverters.INOConvertInt32(e.Row.Cells[Constants.SIZE].Value.ToString(), Constants.ZERO);
        }

        /// <summary>
        /// Rows the is signature.
        /// </summary>
        /// <param name="e">The <see cref="Infragistics.Win.UltraWinGrid.InitializeRowEventArgs"/> instance containing the event data.</param>
        private void RowIsSignature(InitializeRowEventArgs e)
        {
            UCAuthentication renderingAuth = new UCAuthentication();
            UCAuthentication editingAuth = new UCAuthentication();
            UltraControlContainerEditor ctrlEditor = new UltraControlContainerEditor();
            AuthenticationObj AuthenticationObject = new AuthenticationObj();
            e.Row.Height = renderingAuth.Height;
            renderingAuth.AuthenticationObject = AuthenticationObject;
            editingAuth.AuthenticationObject = AuthenticationObject;
            ctrlEditor.RenderingControl = renderingAuth;
            ctrlEditor.RenderingControlPropertyName = Constants.AUTHENTICATION_OBJECT;
            ctrlEditor.EditingControl = editingAuth;
            ctrlEditor.EditingControlPropertyName = Constants.AUTHENTICATION_OBJECT;
            renderingAuth.Font = new Font(new FontFamily(Constants.SANS_SERF), (float)8.25);
            editingAuth.Font = new Font(new FontFamily(Constants.SANS_SERF), (float)8.25);
            e.Row.Cells[Constants.CONTROL].EditorComponent = ctrlEditor;
        }

        /// <summary>
        /// Rows the is combo.
        /// </summary>
        /// <param name="e">The <see cref="Infragistics.Win.UltraWinGrid.InitializeRowEventArgs"/> instance containing the event data.</param>
        private void RowIsCombo(InitializeRowEventArgs e)
        {
            ValueList combo = new ValueList();
            combo.ValueListItems.AddRange(CreateValueListItemArray(e.Row.Cells[Constants.RESPONSES].Value.ToString(), true));
            e.Row.Band.Columns[Constants.CONTROL].ValueList = combo;
            e.Row.Band.Columns[Constants.CONTROL].Style = Infragistics.Win.UltraWinGrid.ColumnStyle.DropDownValidate;
            e.Row.Band.Columns[Constants.TEXT].MaxWidth = Constants.THREE_HUNDRED;
        }

        /// <summary>
        /// Rows the is radio.
        /// </summary>
        /// <param name="e">The <see cref="Infragistics.Win.UltraWinGrid.InitializeRowEventArgs"/> instance containing the event data.</param>
        private void RowIsRadio(InitializeRowEventArgs e)
        {
            bool showText = Convert.ToBoolean(Convert.ToInt32(e.Row.Cells[Constants.SHOW_TEXT].Value));
            e.Row.Band.Columns[Constants.CONTROL].MaxWidth = Constants.THREE_HUNDRED;
            e.Row.Band.Columns[Constants.CONTROL].MinWidth = Constants.THREE_HUNDRED;
            UltraOptionSet optionSet = new UltraOptionSet();
            optionSet.Items.AddRange(CreateValueListItemArray(e.Row.Cells[Constants.RESPONSES].Value.ToString(), showText));
            if (!showText)
            {
                optionSet.ItemSpacingHorizontal = Constants.SIXTY_FIVE;
            }
            optionSet.Value = e.Row.Cells[Constants.CONTROL].Value;
            e.Row.Cells[Constants.CONTROL].EditorComponent = optionSet;
        }

        /// <summary>
        /// Creates the value list item array.
        /// </summary>
        /// <param name="responseList">The response list.</param>
        /// <param name="displayText">if set to <c>true</c> [display text].</param>
        /// <returns></returns>
        private ValueListItem[] CreateValueListItemArray(string responseList, bool displayText)
        {
            string[] responses = responseList.Split(';');
            string text = string.Empty;
            ValueListItem[] valueListItems = new ValueListItem[responses.Count()];
            ValueListItem item;
            int itemIndex = Constants.ZERO;
            foreach (string response in responses)
            {
                string[] splitResponse = response.Split(',');
                if (displayText)
                {
                    text = splitResponse[Constants.ONE].Trim();
                }
                else
                {
                    text = Constants.SPACE_1;
                }
                item = new ValueListItem(splitResponse[Constants.ZERO].Trim(), text);
                valueListItems[itemIndex] = item;
                itemIndex++;
            }
            return valueListItems;
        }

        /// <summary>
        /// Handles the Click event of the btnPrint control.
        /// </summary>
        /// <param name="sender">The source of the event.</param>
        /// <param name="e">The <see cref="System.EventArgs"/> instance containing the event data.</param>
        private void btnPrint_Click(object sender, EventArgs e)
        {
            CurrentPageNumber = 1;
            foreach (UltraGridChildBand band in gridQuestions.Rows[0].ChildBands)
            {
                gridQuestions.ActiveRowScrollRegion.ScrollRowIntoView(band.Rows[0]);
            }
            if (printDialog.ShowDialog() == DialogResult.OK)
            {
                gridPrinter.PrinterSettings.PrinterName = printDialog.PrinterSettings.PrinterName;
                //may want to put a printing splash page here, because this can take a while
                List<PageInfoObj> Pages = new List<PageInfoObj>();
                int currentStartIndex = Constants.ZERO;
                foreach (UltraGridChildBand band in gridQuestions.Rows[Constants.ZERO].ChildBands)
                {
                    if (band.Rows[Constants.ZERO].Cells[Constants.TYPE].Value.ToString() == Constants.PAGE_BREAK ||
                        band.Index == gridQuestions.Rows[Constants.ZERO].ChildBands.Count - Constants.ONE)
                    {
                        Pages.Add(new PageInfoObj(currentStartIndex, band.Index));
                        currentStartIndex = band.Index + Constants.ONE;
                    }
                }
                foreach (PageInfoObj pageInfo in Pages)
                {
                    foreach (UltraGridChildBand band in gridQuestions.Rows[Constants.ZERO].ChildBands)
                    {
                        if (band.Index < pageInfo.StartIndex || band.Index > pageInfo.EndIndex ||
                            band.Rows[Constants.ZERO].Cells[Constants.TYPE].Value.ToString() == Constants.PAGE_BREAK)
                        {
                            HideOrShowBandRows(band, true);
                        }
                        else
                        {
                            HideOrShowBandRows(band, false);
                        }
                    }
                    gridPrinter.Grid = gridQuestions;
                    gridPrinter.FitWidthToPages = Constants.ONE;
                    gridPrinter.Print();
                }
                foreach (UltraGridChildBand band in gridQuestions.Rows[Constants.ZERO].ChildBands)
                {
                    HideOrShowBandRows(band, false);
                }
            }
        }

        /// <summary>
        /// Hides the or show band rows.
        /// </summary>
        /// <param name="band">The band.</param>
        /// <param name="hidden">if set to <c>true</c> [hidden].</param>
        private void HideOrShowBandRows(UltraGridChildBand band, bool hidden)
        {
            foreach (UltraGridRow row in band.Rows)
            {
                row.Hidden = hidden;
            }
        }
    }
}
